"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BaseFieldInput = BaseFieldInput;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactIntl = require("react-intl");

var _get = _interopRequireDefault(require("lodash/get"));

var _dataTypes = require("../../../constants/dataTypes");

var _formatHelpers = require("../../../helpers/formatHelpers");

var _configContextInputs = require("../../../helpers/configContextInputs");

var _configHelpers = require("../../../helpers/configHelpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const propTypes = {
  config: _propTypes.default.object.isRequired,
  intl: _reactIntl.intlShape.isRequired,
  name: _propTypes.default.string,
  placeholder: _propTypes.default.string,
  readOnly: _propTypes.default.bool,
  recordType: _propTypes.default.string,
  rootPath: _propTypes.default.string,
  value: _propTypes.default.string,
  valueDescriptor: _propTypes.default.object,
  onCommit: _propTypes.default.func
};

function BaseFieldInput(props) {
  const {
    config,
    intl,
    name,
    placeholder,
    readOnly,
    recordType,
    rootPath,
    value,
    valueDescriptor,
    onCommit
  } = props;

  if (readOnly) {
    let label = value;

    if (valueDescriptor) {
      const valueConfig = valueDescriptor[_configHelpers.configKey];
      const extensionParentConfig = (0, _get.default)(valueConfig, 'extensionParentConfig');
      const messages = (0, _get.default)(valueConfig, 'messages');
      const rootPathParts = rootPath ? rootPath.split('/') : [];
      const pathParts = value ? value.split('/') : [];
      const level = pathParts.length - rootPathParts.length;

      if (messages) {
        let message;

        if (extensionParentConfig && extensionParentConfig.dataType === _dataTypes.DATA_TYPE_STRUCTURED_DATE) {
          // Special case for constructing the label for fields in structured dates.
          if (level > 1) {
            label = (0, _formatHelpers.formatExtensionFieldName)(intl, valueConfig);
          } else {
            message = messages.name || messages.fullName;
          }
        } else {
          if (level > 1) {
            message = messages.fullName;
          }

          if (!message) {
            message = messages.name || messages.fullName;
          }
        }

        if (message) {
          label = intl.formatMessage(message);
        }
      }
    }

    return _react.default.createElement("div", null, _react.default.createElement("span", null, label));
  }

  const sortComparator = (optionA, optionB) => {
    const labelA = optionA.label;
    const labelB = optionB.label;
    return labelA.localeCompare(labelB, config.locale, {
      sensitivity: 'base'
    });
  };

  return _react.default.createElement(_configContextInputs.OptionPickerInput, {
    blankable: false,
    name: name,
    placeholder: placeholder,
    source: (0, _configHelpers.getRecordFieldOptionListName)(recordType, rootPath),
    value: value,
    sortComparator: sortComparator,
    onCommit: onCommit
  });
}

BaseFieldInput.propTypes = propTypes;

var _default = (0, _reactIntl.injectIntl)(BaseFieldInput);

exports.default = _default;